@@ -18,7 +18,8 @@ class ErrorReportingMiddleware(object):
     def __init__(self, app):
         self.app = app
 
-    def format_exception(self, exc_info):
+    @staticmethod
+    def format_exception(exc_info):
         dummy_file = six.StringIO()
         hook = cgitb.Hook(file=dummy_file)
         hook(*exc_info)
@@ -28,6 +29,7 @@ class ErrorReportingMiddleware(object):
             return [dummy_file.getvalue()]
 
     def __call__(self, environ, start_response):
+        # noinspection PyBroadException
         try:
             return self.app(environ, start_response)
         except:
